@@ -16,7 +16,7 @@ QAttachmentWidget::QAttachmentWidget(QString fileName, qint64 fileSize, QWidget
 {
 	ui.setupUi(this);
 
-	ui.lFileName->setText(fileName);
+	ui.lFileName->setText(QString::fromLocal8Bit(fileName.toStdString().c_str(), fileName.length()));
 	ui.lFileSize->setText(QString("%1 KB").arg(fileSize/1024));
 }
 
