@@ -84,9 +84,11 @@ QNoteEditWindow::QNoteEditWindow(Note& note, bool bIsNewNote, QWidget *parent)
 	QAction* actAddTag = new QAction(QIcon(":/IconAdd/general_tag.png"), "Add tag", this);
 	QAction* actAttachFile = new QAction(QIcon(":/IconAdd/email_attachment.png"), "Attach file", this);
 	QAction* actEmailNote = new QAction(/*QIcon(":/IconAdd/general_email.png"),*/ "Email note", this);
-	QAction* actGps = new QAction(QIcon(":/IconAdd/gps_location.png"), "Location", this);
 	QAction* actSaveNote = new QAction(QIcon(":/IconAdd/notes_save.png"), "Save note", this);
 
+	// GPS action is class-field and defined in .h file
+	actGps = new QAction(QIcon(":/IconAdd/gps_location.png"), "Location", this);
+
 	//QAction* actZoomin = new QAction(QIcon(":/IconAdd/note_zoomin.png"), "Zoom In", this);
 	//QAction* actZoomout = new QAction(QIcon(":/IconAdd/note_zoomout.png"), "Zoom Out", this);
 
@@ -294,6 +296,7 @@ void QNoteEditWindow::attachFile()
 			QAttachmentWidget attWidget(fi);
 			QByteArray widgetIcon = QAttachmentWidget::toPng(&attWidget);
 			contentType = QHtmlContentHandler::getContentType(fileName);
+			qDebug() << __FUNCTION__ << fileName;
 			htmlNode = "<" + htmlTag + " filename=\"" + fi.fileName() + "\" src=\"" + fileName + "\"><img src=\"data:image/png;base64," + widgetIcon.toBase64() + "\"/></" + htmlTag + ">";
 			break;
 		}
@@ -426,6 +429,11 @@ void QNoteEditWindow::zoomoutView()
 void QNoteEditWindow::startGpsLocationUpdate()
 {
 #ifdef Q_WS_MAEMO_5
+	actGps->setEnabled(false);
+
+	if(source)
+		delete source;
+
 	source = QGeoPositionInfoSource::createDefaultSource(this);
 	if (source)
 	{
@@ -445,11 +453,11 @@ void QNoteEditWindow::positionUpdated(const QGeoPositionInfo& update)
 	m_Note.attributes.latitude = update.coordinate().latitude();
 	m_Note.attributes.longitude = update.coordinate().longitude();
 
-	qDebug() << m_Note.attributes.latitude << m_Note.attributes.longitude;
+	//qDebug() << m_Note.attributes.latitude << m_Note.attributes.longitude;
 
 	displayInformationBox(trUtf8("GPS position updated"));
 	source->stopUpdates();
-	delete source;
-	source = NULL;
+
+	actGps->setEnabled(true);
 }
 #endif
