@@ -16,6 +16,7 @@ public:
 public slots:
 	void searchNote();
 	void openTagSelectionDialog();
+	void openNotebookSelectionDialog();
 	void setTag(bool state, Tag tag);
 
 signals:
@@ -25,6 +26,7 @@ private:
     Ui::QNoteSearchDialogClass ui;
     QWidget*	m_parent;
     QList<QStringList>	selectedTagsList;
+    QStringList			selectedNotebook;
 };
 
 #endif // QNOTESEARCHDIALOG_H
