@@ -471,12 +471,12 @@ void QResourceHandlerDialog::storeResource()
 {
 	Resource r;
 
-	if(QvernoteAPI::Instance()->loadResourceByHash(r, m_Note.guid, QByteArray::fromHex(m_resourceHash.toAscii()).data()) == true)
+	if(QvernoteAPI::Instance()->loadResourceByHash(r, m_Note.guid, m_resourceHash) == true)
 	{
 		QString fileName = QFileDialog::getSaveFileName(
 				this,
 				tr("Save resource"),
-				"/MyDocs/" + QString::fromStdString(r.attributes.fileName),
+				"/MyDocs/" + QString::fromUtf8(r.attributes.fileName.c_str(), r.attributes.fileName.size()),
 				tr("Images (*.png *.gif *.jpg);;Audio (*.wav *.mpg *.amr *.mp3);;Documents (*.pdf);;Other (*)"));
 
 		if(fileName.size() > 0)
@@ -510,7 +510,7 @@ void QResourceHandlerDialog::previewResource()
 	setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 #endif
 
-	if(QvernoteAPI::Instance()->loadResourceByHash(r, m_Note.guid, QByteArray::fromHex(m_resourceHash.toAscii()).data()) == true)
+	if(QvernoteAPI::Instance()->loadResourceByHash(r, m_Note.guid, m_resourceHash) == true)
 	{
 		switch(QEnmlContentHandler::decodeEnmlMediaType(QString::fromStdString(r.mime))) {
 		case QEnmlContentHandler::MT_PDF:
