@@ -15,11 +15,19 @@ QNotebookListItemWidget::QNotebookListItemWidget(Notebook& notebook, QvernoteAPI
 	//else
 	//	ui.lDeleteMark->setVisible(false);
 
+
 	if(m_Notebook.defaultNotebook)
 	{
 		ui.lNotebookIcon->setPixmap(QPixmap(":/IconAdd/star-32.png"));
 	}
 
+	QStringList blacklistedNotebooks = QvernoteSettings::Instance()->getBlacklistedNotebooks().split(',');
+	if(blacklistedNotebooks.contains(QString::fromStdString(m_Notebook.guid)) && !m_Notebook.guid.empty())
+	{
+		qDebug() << "Notebook is blacklisted: " << m_Notebook.name.c_str();
+		ui.lNotebookIcon->setPixmap(QPixmap(":/IconAdd/general_presence_offline.png"));
+	}
+
 	ui.lNotebookName->setText(QString::fromUtf8(m_Notebook.name.c_str()));
 
 	ui.lNotesCount->setText(QString::number((noteCount == -1)? hEvernote->getNotebookContentsCount(notebook) : noteCount, 10) + trUtf8(" notes"));
