@@ -9,11 +9,14 @@
 #define QPOPPLERSUPPORT_H_
 
 #include <poppler-qt4.h>
+#include <QApplication>
+#include <QPainter>
 #include <QDebug>
 
 class QPopplerSupport
 {
 public:
+	QPopplerSupport() : document(NULL) { }
 	QPopplerSupport(QByteArray& pdfData) {
 		document = Poppler::Document::loadFromData(pdfData);
 
@@ -21,30 +24,44 @@ public:
 			qDebug() << "Error loading PDF document";
 			delete document;
 		}
+
+		documentPages = document->numPages();
 	}
 
 	~QPopplerSupport() {
 		delete document;
 	}
 
-	void renderPage(int pageNumber, QPixmap& pixmap) {
-		if(!document) {
+	void setData(QByteArray& pdfData) {
+		document = Poppler::Document::loadFromData(pdfData);
+
+		if(!document || document->isLocked()) {
+			qDebug() << "Error loading PDF document";
+			delete document;
+		}
+
+		documentPages = document->numPages();
+	}
+
+	bool renderPage(int pageNumber, QPixmap& pixmap) {
+		if(!document || pageNumber+1 > documentPages) {
 			renderNullPage(pixmap);
-			return;
+			return false;
 		}
 
 		Poppler::Page* pdfPage = document->page(pageNumber);
 		if(pdfPage == NULL) {
 			renderNullPage(pixmap);
-			return;
+			return false;
 		}
 
 		pixmap = QPixmap::fromImage(pdfPage->renderToImage());
+		return true;
 	}
 
 private:
 	void renderNullPage(QPixmap& pixmap) {
-		QString invalidPdf = "Invalid PDF";
+		QString invalidPdf = QApplication::translate("QPopplerSupport", "Invalid PDF", 0, QCoreApplication::UnicodeUTF8);
 		QPainter p(&pixmap);
 		int strWidth = p.fontMetrics().width(invalidPdf);
 
@@ -54,5 +71,6 @@ private:
 
 private:
 	Poppler::Document* document;
+	int		documentPages;
 };
 #endif /* QPOPPLERSUPPORT_H_ */
