@@ -11,7 +11,7 @@ class QSyncProgressWidget : public QLabel
 
 public:
     QSyncProgressWidget(QWidget* parent = 0)
-		:QLabel("Please wait", parent) {
+		:QLabel(trUtf8("Please wait"), parent) {
     	setAlignment(Qt::AlignCenter);
     	setAttribute(Qt::WA_TranslucentBackground);
     	setWordWrap(true);
@@ -27,12 +27,12 @@ public:
 
     void showEvent(QShowEvent*) {
 		progressCount = 0;
-		setText(QString("Please wait..."));
+		setText(QString(trUtf8("Please wait...")));
 	}
 
 public slots:
    	void updateProgressData(QString data) {
-   		setText(QString("%1\n\n%2").arg(++progressCount).arg(data));
+   		setText(QString(trUtf8("%1\n\n%2")).arg(++progressCount).arg(data));
    	}
 
 protected:
@@ -42,7 +42,7 @@ protected:
 		p.setBrush(QColor(0, 0, 0, 128));
 		p.setPen(Qt::NoPen);
 		p.drawRoundedRect(rect(), 25, 25);
-		setStyleSheet("color:#999999;font-size:26px");
+		setStyleSheet(trUtf8("color:#999999;font-size:26px"));
 		p.end();
 		QLabel::paintEvent(event);
     }
