@@ -7,12 +7,12 @@ QTrashWindow::QTrashWindow(QWidget *parent)
 {
 	ui.setupUi(this);
 
-	m_pbDeleteSelected.setText("Delete");
-	m_pbRestoreSelected.setText("Restore");
+	m_pbDeleteSelected.setText(trUtf8("Delete"));
+	m_pbRestoreSelected.setText(trUtf8("Restore"));
 	ui.gridLayout_2->setAlignment(ui.lwTrashList, Qt::AlignTop);
 
 	//m_pbDeleteSelected.setIcon(QIcon(":/IconAdd/general_stop.png"));
-	//m_lSelectedCount.setText("0 selected");
+	//m_lSelectedCount.setText(trUtf8("0 selected"));
 	//ui.statusBar->setLayoutDirection(Qt::RightToLeft);
 	//ui.statusbar->addWidget(&m_pbDeleteSelected);
 	ui.statusbar->addWidget(&m_pbRestoreSelected);
@@ -66,8 +66,8 @@ void QTrashWindow::deleteSelectedNotes()
 
 	if(m_iSelectedCount == 0 ||
 	       QMessageBox::question(this,
-	    		   "Confirm",
-	    		   QString("Ready to permanently delete %1 notes?").arg(m_iSelectedCount),
+	    		   trUtf8("Confirm"),
+	    		   QString(trUtf8("Ready to permanently delete %1 notes?")).arg(m_iSelectedCount),
 	    		   QMessageBox::Yes|QMessageBox::No,
 	    		   QMessageBox::Yes) == QMessageBox::No)
 			return;
@@ -84,7 +84,7 @@ void QTrashWindow::deleteSelectedNotes()
 		{
 			if(m_hEvernote->expungeNote(currItem->getNote().guid) == false)
 			{
-				displayError("Unable to expunge note", QString(m_hEvernote->getLastErrorString().c_str()));
+				displayError(trUtf8("Unable to expunge note"), QString(m_hEvernote->getLastErrorString().c_str()));
 			}
 			else
 			{
@@ -109,8 +109,8 @@ void QTrashWindow::restoreSelectedNotes()
 
 	if(m_iSelectedCount == 0 ||
 		   QMessageBox::question(this,
-				   "Confirm",
-				   QString("Ready to restore %1 notes?").arg(m_iSelectedCount),
+				   trUtf8("Confirm"),
+				   QString(trUtf8("Ready to restore %1 notes?")).arg(m_iSelectedCount),
 				   QMessageBox::Yes|QMessageBox::No,
 				   QMessageBox::Yes) == QMessageBox::No)
 			return;
@@ -127,7 +127,7 @@ void QTrashWindow::restoreSelectedNotes()
 		{
 			if(m_hEvernote->undeleteNote(currItem->getNote()) == false)
 			{
-				displayError("Unable to restore note", QString(m_hEvernote->getLastErrorString().c_str()));
+				displayError(trUtf8("Unable to restore note"), QString(m_hEvernote->getLastErrorString().c_str()));
 			}
 			else
 			{
