@@ -111,7 +111,7 @@ public:
 	bool	undeleteNote(Note& note);
 	bool 	loadTrashNoteList(vector<Note>& noteList);
 	bool	loadResource(Resource& loadedResource, Guid resourceGuid);
-	bool	loadResourceByHash(Resource& loadedResource, Guid noteGuid, string contentHash);
+	bool	loadResourceByHash(Resource& loadedResource, Guid noteGuid, QString hexContentHash);
 
 	bool loadNotebookList();
 	bool getDefaultNotebook(Notebook& defaultNotebook);
