@@ -54,7 +54,7 @@ public:
 	bool getTrashNotes(vector<Note>& noteList);
 	bool getFavoriteNotes(vector<Note>& noteList);
 	bool getResource(Resource& loadedResource, Guid resourceGuid);
-	bool getResourceByHash(Resource& loadedResource, Guid noteGuid, string contentHash);
+	bool getResourceByHash(Resource& loadedResource, Guid noteGuid, QString  hexContentHash);
 
 	bool getNoteThumbnail(Guid noteGuid, QByteArray& thumbnail);
 	bool setNoteThumbnail(Note& note, QByteArray& thumbnail);
