@@ -11,8 +11,12 @@
 int main(int argc, char *argv[])
 {
 	QApplication a(argc, argv);
+	a.setApplicationName("Qvernote");
+	QTranslator aTranslator;
+  	aTranslator.load("po/qvernote_" + QLocale::system().name());
+  	a.installTranslator(&aTranslator);
 
 	Qvernote wndLoader;
 	wndLoader.Init();
-    return a.exec();
+   return a.exec();
 }
